Documentation
¶
Index ¶
Constants ¶
const ( // DefaultPath is the default file path used to mount config. DefaultPath string = "/etc/skpr/data/config.json" )
Variables ¶
var ( // ErrNotFound is returned when Skpr configuration cannot be found. ErrNotFound = errors.New("configuration not found") )
Functions ¶
This section is empty.
Types ¶
type Config ¶
type Config struct {
// contains filtered or unexported fields
}
Config represents the config.
func (*Config) GetWithFallback ¶
GetWithFallback returns the configured value of a given key, and the fallback value if no key does not exist.
Click to show internal directories.
Click to hide internal directories.